/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      kappenh
 *   Co-authors:
 *      ...
 *
 */

#ifndef _Highscore_H__
#define _Highscore_H__

#include <string>
#include <vector>

#include "OrxonoxPrereqs.h"
#include "core/config/Configurable.h"
#include "util/Singleton.h"

// tolua_begin
namespace orxonox
{
    class _OrxonoxExport Highscore
    // tolua_end
     : public Singleton<Highscore>, public Configurable
    { //tolua_export
        friend class Singleton<Highscore>;
        public:
            Highscore();              // Constructor
            void setConfigValues(); // Inherited function

            bool storeScore(const std::string& level, int points, PlayerInfo* player);
            int getHighestScoreOfGame(const std::string& game);

            // tolua_begin
            inline unsigned int getNumberOfHighscores()
                { return this->highscores_.size(); }
            inline const std::string& getHighscore(unsigned int index)
                { return this->highscores_[index]; }

            static Highscore& getInstance()
                { return Singleton<Highscore>::getInstance(); }
            // tolua_end

        private:
            std::vector<std::string> highscores_;
            static Highscore* singletonPtr_s;
    }; //tolua_export

} //tolua_export

#endif /* _Highscore_H__ */
